@@ -1,9 +1,9 @@
+use elbus::ipc::{Client, Config};
+use elbus::rpc::{DummyHandlers, Rpc, RpcClient};
 /// Demo of client RPC with no handler, which just calls methods
 ///
 /// use client_rpc_handler example to test client/server
-use elbus::empty_payload;
-use elbus::ipc::{Client, Config};
-use elbus::rpc::{DummyHandlers, Rpc, RpcClient};
+use elbus::{empty_payload, QoS};
 use serde::Deserialize;
 use std::collections::HashMap;
 
@@ -22,19 +22,25 @@ async fn main() {
     // create RPC with no handlers
     let mut rpc = RpcClient::new(client, DummyHandlers {});
     // call the method with no confirm
-    rpc.call0(target, "test", empty_payload!()).await.unwrap();
-    let mut payload = HashMap::new();
+    rpc.call0(target, "test", empty_payload!(), QoS::Processed)
+        .await
+        .unwrap();
+    let mut payload: HashMap<&str, u32> = HashMap::new();
     payload.insert("value", 10);
     // call a method with confirm to make sure the value is added
     rpc.call(
         target,
         "add",
         rmp_serde::to_vec_named(&payload).unwrap().into(),
+        QoS::Processed,
     )
     .await
     .unwrap();
     // call the method to read the sum
-    let result = rpc.call(target, "get", empty_payload!()).await.unwrap();
+    let result = rpc
+        .call(target, "get", empty_payload!(), QoS::Processed)
+        .await
+        .unwrap();
     let amount: Amount = rmp_serde::from_read_ref(result.payload()).unwrap();
     println!("{}", amount.value);
 }
