@@ -236,7 +236,7 @@ pub trait Rpc {
     /// pub/sub and send broadcast messages)
     fn client(&self) -> Arc<Mutex<(dyn AsyncClient + 'static)>>;
     async fn notify(
-        &self,
+        &mut self,
         target: &str,
         data: Cow<'async_trait>,
         qos: QoS,
@@ -251,7 +251,7 @@ pub trait Rpc {
     ) -> Result<OpConfirm, Error>;
     /// Call the method and get the response
     async fn call(
-        &self,
+        &mut self,
         target: &str,
         method: &str,
         params: Cow<'async_trait>,
@@ -262,7 +262,7 @@ pub trait Rpc {
 
 #[allow(clippy::module_name_repetitions)]
 pub struct RpcClient {
-    call_id: atomic::AtomicU32,
+    call_id: u32,
     timeout: Option<Duration>,
     client: Arc<Mutex<dyn AsyncClient>>,
     processor_fut: Arc<std::sync::Mutex<JoinHandle<()>>>,
@@ -423,7 +423,7 @@ impl RpcClient {
             })
         });
         Self {
-            call_id: atomic::AtomicU32::new(1),
+            call_id: 0,
             timeout,
             client,
             processor_fut,
@@ -433,14 +433,12 @@ impl RpcClient {
         }
     }
     #[inline]
-    fn generate_call_id(&self) -> u32 {
-        self.call_id
-            .fetch_update(
-                atomic::Ordering::SeqCst,
-                atomic::Ordering::SeqCst,
-                |call_id| Some(if call_id == u32::MAX { 1 } else { call_id + 1 }),
-            )
-            .unwrap()
+    fn increase_call_id(&mut self) {
+        if self.call_id == u32::MAX {
+            self.call_id = 1;
+        } else {
+            self.call_id += 1;
+        }
     }
 }
 
@@ -452,7 +450,7 @@ impl Rpc for RpcClient {
     }
     #[inline]
     async fn notify(
-        &self,
+        &mut self,
         target: &str,
         data: Cow<'async_trait>,
         qos: QoS,
@@ -481,13 +479,14 @@ impl Rpc for RpcClient {
     ///
     /// Will panic on poisoned mutex
     async fn call(
-        &self,
+        &mut self,
         target: &str,
         method: &str,
         params: Cow<'async_trait>,
         qos: QoS,
     ) -> Result<RpcEvent, RpcError> {
-        let call_id = self.generate_call_id();
+        self.increase_call_id();
+        let call_id = self.call_id;
         let payload = prepare_call_payload(method, &call_id.to_le_bytes());
         let (tx, rx) = oneshot::channel();
         self.calls.lock().unwrap().insert(call_id, tx);
